@@ -1,4 +1,4 @@
-package Sim::OPT::Interlinear;
+#package Sim::OPT::Interlinear;
 
 # INTERLINEAR, v. 0.0011
 # Author: Gian Luca Brunetti, Politecnico di Milano. (gianluca.brunetti@polimi.it)
@@ -20,13 +20,13 @@ use feature 'say';
 no strict;
 no warnings;
 
-use Sim::OPT;
-use Sim::OPT::Morph;
-use Sim::OPT::Sim;
-use Sim::OPT::Report;
-use Sim::OPT::Descend;
-use Sim::OPT::Takechance;
-use Sim::OPT::Parcoord3d;
+#use Sim::OPT;
+#use Sim::OPT::Morph;
+#use Sim::OPT::Sim;
+#use Sim::OPT::Report;
+#use Sim::OPT::Descend;
+#use Sim::OPT::Takechance;
+#use Sim::OPT::Parcoord3d;
 
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart );
@@ -41,7 +41,7 @@ $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, m
 
 my $maxloops= 1000;
 my $sourcefile = "/home/luca/int/starcloud.csv";
-my $newfile = $sourcefile . "_cy_new.csv";
+my $newfile = $sourcefile . "_cy_1_1_1_new.csv";
 my $report = $newfile . "_report.txt";
 my @mode = ( "wei" ); # #"wei" is weighted gradient linear interpolation of the nearest neighbours.
 #my @mode = ( "near" ); # "nea" means "nearest neighbour"
@@ -266,7 +266,7 @@ sub pythagoras
 
 sub weightvals1
 {
-  my ( $elt1, $boxgrads_ref, $boxdists_ref, $boxors_ref, $minreq_forcalc, $factbag_ref, $levbag_ref, $stepbag_ref, $elt2, $factlevels_ref, $maxdist, $el3, $elt3, $condweight, $distn_ref, $el0, $elt0 ) = @_;
+  my ( $elt1, $boxgrads_ref, $boxdists_ref, $boxors_ref, $minreq_forcalc, $factbag_ref, $levbag_ref, $stepbag_ref, $elt2, $factlevels_ref, $maxdist, $el3, $elt3, $condweight ) = @_;
   my @boxgrads = @{ $boxgrads_ref }; #say $tee "weightvals1 \@boxgrads: " . dump( @boxgrads );
   my @boxdists = @{ $boxdists_ref }; #say $tee "weightvals1 \@boxdists: " . dump( @boxdists );
   my @boxors = @{ $boxors_ref }; #say $tee "weightvals1 \@boxors: " . dump( boxors );
@@ -274,8 +274,6 @@ sub weightvals1
   my @levbag = @{ $levbag_ref }; #say $tee "weightvals12 \@levbag: " . dump( @levbag );
   my @stepbag = @{ $stepbag_ref }; #say $tee "weightvals12 \@stepbag: " . dump( @stepbag );
   my %factlevels = %{ $factlevels_ref }; #say $tee "weightvals12 \%factlevels: " . dump( %factlevels );
-  say $tee "\$maxdist: " .dump( $maxdist );
-  #say $tee "\$distn_ref: " .dump( $distn_ref );
   #say $tee "weightvals1 \$maxdist: " . dump( $maxdist );
 
   #if ( ref( $minreq_forcalc ) )
@@ -295,9 +293,7 @@ sub weightvals1
   my @newboxdists;
   foreach my $or ( @boxors )
   {
-    say $tee "weightvals12 \@boxors: " . dump( @boxors );
-    my $hsh_ref = calcdist( { elt1 => $elt1, el1 => $or, factlevels_ref => \%factlevels, maxdist => $maxdist,
-      el3 => $el3, elt3 => $elt3, condweight => $condweight, distn_ref => $distn_ref, el0 => $el0, elt0 => $elt0 } ); #say $tee "555 \$hsh_ref: " . dump( $hsh_ref );
+    my $hsh_ref = calcdist( $elt1, $or, \%factlevels, $maxdist, $el3, $elt3, $condweight ); #say $tee "555 \$hsh_ref: " . dump( $hsh_ref );
     my %hsh = %{ $hsh_ref }; #say $tee "555 \$elt1: " . dump( $elt1 ); #say $tee "555 \$or: " . dump( $or );
     my $dist = $hsh{dist}; #say $tee "555 \$dist: " . dump( $dist );
     push ( @newboxdists, $dist );
@@ -355,7 +351,6 @@ sub weightvals1
 } #END SUB weightvals1
 
 
-
 sub weightvals_merge
 {
   my ( $vals_ref, $strengths_ref, $minreq_formerge, $maxdist ) = @_;
@@ -426,168 +421,138 @@ sub weightvals_merge
 
 sub calcdist
 {
-  my ( $h_ref ) = @_;
-  my %h = %{ $h_ref };
-
-  my $el1 = $h{el1}; #say $tee "OUT CALCDIST \$el1: " .dump( \$el1 );
-  my $elt1 = $h{elt1}; #say $tee "OUT CALCDIST \$elt1: " .dump( \$elt1 );
-  my $factlevels_ref = $h{factlevels_ref}; #say $tee "OUT CALCDIST \$factlevels_ref: " .dump( \$factlevels_ref );
-  my $maxdist = $h{maxdist}; #say $tee "OUT CALCDIST \$maxdist: " .dump( \$maxdist );
-  my $el3 = $h{el3}; #say $tee "OUT CALCDIST \$el3: " .dump( \$el3 );
-  my $elt3 = $h{elt3}; #say $tee "OUT CALCDIST \$elt3: " .dump( \$elt3 );
-  my $condweight = $h{condweight}; #say $tee "OUT CALCDIST \$condweight: " .dump( \$condweight );
-  my $distn_ref = $h{distn_ref}; #say $tee "OUT CALCDIST \$distn_ref: " .dump( \$distn_ref );
-  my $el0 = $h{el0}; #say $tee "OUT CALCDIST \$el0: " .dump( \$el0 );
-  my $elt0 = $h{elt0}; #say $tee "OUT CALCDIST \$elt0: " .dump( \$elt0 );
-  my $signal = $h{signal}; #say $tee "OUT CALCDIST \$signal: " .dump( \$signal );
-
+  my ( $el1, $elt1, $factlevels_ref, $maxdist, $el3, $elt3, $condweight ) = @_;
   my %factlevels = %{ $factlevels_ref };
-  my %distn = %{ $distn_ref }; #say $tee "OUT0 CALCDIST \%distn: " .dump( \%distn );
-  if ( ( $distn{$el0}{$elt0} eq "y" ) or ( $signal eq "signal" ) )
-  { #say $tee "IN002 CALCDIST \%distn: " .dump( \%distn );
-    my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } );
-    my $dist;
-    my ( @factbag, @levbag, @stepbag, @da1, @da1par, @da2, @da2par, @diff2 );
+  my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } );
+  my $dist;
+  my ( @factbag, @levbag, @stepbag, @da1, @da1par, @da2, @da2par, @diff2 );
 
-    #say $tee "777\scalar( \@diff1 ): " . dump( scalar( @diff1 ) );
-    if ( scalar( @diff1 ) > 0 )
-    {
-      @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); #say $tee "777b \@diff2: " . dump( @diff2 );
+  #say $tee "777\scalar( \@diff1 ): " . dump( scalar( @diff1 ) );
+  if ( scalar( @diff1 ) > 0 )
+  {
+    @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); #say $tee "777b \@diff2: " . dump( @diff2 );
 
-      my %h1 = map { split( /-/ , $_ ) } @diff1; #say $tee "THEN \%h1: " . dump( %h1 );
-      @da1 = keys %h1; #say $tee "THEN \@da1: " . dump( @da1 );
-      @da1par = values %h1; #say $tee "\@da1par: " . dump( @da1par );
-      my %h2 = map { split( /-/ , $_ ) } @diff2; #say $tee "THEN \%h2: " . dump( %h2 );
-      @da2 = keys %h2; #say $tee "THEN \@da2: " . dump( @da2 );
-      @da2par = values %h2; #say $tee "\@da2par: " . dump( @da2par );
+    my %h1 = map { split( /-/ , $_ ) } @diff1; #say $tee "THEN \%h1: " . dump( %h1 );
+    @da1 = keys %h1; #say $tee "THEN \@da1: " . dump( @da1 );
+    @da1par = values %h1; #say $tee "\@da1par: " . dump( @da1par );
+    my %h2 = map { split( /-/ , $_ ) } @diff2; #say $tee "THEN \%h2: " . dump( %h2 );
+    @da2 = keys %h2; #say $tee "THEN \@da2: " . dump( @da2 );
+    @da2par = values %h2; #say $tee "\@da2par: " . dump( @da2par );
 
-      my $c = 0;
-      foreach my $e ( @da1par )
-      { #say $tee "\$e: " . dump( $e );
-        my $e = $da1par[$c];
-        my $ei = $da2par[$c]; #say $tee "22 \$ei: " . dump( $ei );
-        my $fact = $da1[$c]; #say $tee "22 \$fact: " . dump( $fact );
-        my $diffpar = abs( $e - $ei ); #say $tee "22 \$diffpar: " . dump( $diffpar ); say $tee "22 \$factlevels{stepsizes}{\$fact}: " . dump( $factlevels{stepsizes}{$fact} );
-        if ( ( $fact ne "" ) and ( $diffpar ne "" ) and ( $factlevels{stepsizes}{$fact} ne "" ) )
-        {
-          push ( @factbag, $fact );
-          push ( @levbag, $diffpar );
-          push ( @stepbag, $factlevels{stepsizes}{$fact} );
-        }
-        #say $tee "777b \@factbag : " . dump( @factbag ); say $tee "777b \@levbag : " . dump( @levbag ); say $tee "777b \@stepbag : " . dump( @stepbag );
-        $c++;
-      }
-    }
-    unless ( ( scalar( @levbag ) == 0 ) or ( scalar( @factbag ) == 0 ) or ( scalar( @stepbag ) == 0 ) )
-    {
-      my $ordist = scalar( @levbag ); #say $tee "\$ordist: " . dump( $ordist );
-      my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); #say $tee "776b\$rawdist: " . dump( $rawdist );
-      my ( $dist, $strength );
-
-      if ( $maxdist ne "" )
+    my $c = 0;
+    foreach my $e ( @da1par )
+    { #say $tee "\$e: " . dump( $e );
+      my $e = $da1par[$c];
+      my $ei = $da2par[$c]; #say $tee "22 \$ei: " . dump( $ei );
+      my $fact = $da1[$c]; #say $tee "22 \$fact: " . dump( $fact );
+      my $diffpar = abs( $e - $ei ); #say $tee "22 \$diffpar: " . dump( $diffpar ); say $tee "22 \$factlevels{stepsizes}{\$fact}: " . dump( $factlevels{stepsizes}{$fact} );
+      if ( ( $fact ne "" ) and ( $diffpar ne "" ) and ( $factlevels{stepsizes}{$fact} ne "" ) )
       {
-        $dist = ( $rawdist / $maxdist );
-        $strength = ( 1 - $dist );
+        push ( @factbag, $fact );
+        push ( @levbag, $diffpar );
+        push ( @stepbag, $factlevels{stepsizes}{$fact} );
       }
-
-      if ( ( $el3 ne "" ) and ( $elt3 ne "" ) and ( $condweight = "yes") )
-      {
-        $strength = ( $strength * $el3 * $elt3 );
-      }
-      my $h_r = { dist => $dist, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1,
-        diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par,
-        signal => $h{signal} }; #say $tee "779\$h_r: " . dump( $h_r );
-      return( $h_r );
+      #say $tee "777b \@factbag : " . dump( @factbag ); say $tee "777b \@levbag : " . dump( @levbag ); say $tee "777b \@stepbag : " . dump( @stepbag );
+      $c++;
     }
   }
+  unless ( ( scalar( @levbag ) == 0 ) or ( scalar( @factbag ) == 0 ) or ( scalar( @stepbag ) == 0 ) )
+  {
+    my $ordist = scalar( @levbag ); #say $tee "\$ordist: " . dump( $ordist );
+    my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); #say $tee "776b\$rawdist: " . dump( $rawdist );
+    my ( $dist, $strength );
+
+    if ( $maxdist ne "" )
+    {
+      $dist = ( $rawdist / $maxdist );
+      $strength = ( 1 - $dist );
+    }
+
+    if ( ( $el3 ne "" ) and ( $elt3 ne "" ) and ( $condweight = "yes") )
+    {
+      $strength = ( $strength * $el3 * $elt3 );
+    }
+    return( { dist => $disfactlevelst, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1, diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par } );
+  }
 }
 
 
 sub calcdistgrad
 {
-  my ( $el1, $elt1, $factlevels_ref, $minreq, $maxdist, $el3, $elt3, $condweight, $distn_ref, $el0, $elt0 ) = @_; #say $tee "777c\$el1: " . dump( $el1 ); say $tee "777c\$elt1: " . dump( $elt1 ); say $tee "777c\$minreq: " . dump( $minreq );
+  my ( $el1, $elt1, $factlevels_ref, $minreq, $maxdist, $el3, $elt3, $condweight ) = @_; #say $tee "777c\$el1: " . dump( $el1 ); say $tee "777c\$elt1: " . dump( $elt1 ); say $tee "777c\$minreq: " . dump( $minreq );
   my %factlevels = %{ $factlevels_ref };
-  my %distn = %{ $distn_ref }; #say $tee "OUT CALCDISTRGRAD\%distn: " .dump( \%distn );
-  if ( $distn{$el0}{$elt0} eq "y" )
-  { #say $tee "IN CALCDISTRGRAD \%distn: " .dump( \%distn );
-    my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } ); #say $tee "777\@diff1: " . dump( @diff1 );
-    my $dist;
-    my ( @factbag, @levbag, @stepbag, @da1, @da1par, @da2, @da2par, @diff2 );
-    #say $tee "777\scalar( \@diff1 ): " . dump( scalar( @diff1 ) ); say $tee "777\$minreq: " . dump( $minreq );
-    if ( ( scalar( @diff1 ) > 0 ) and ( scalar( @diff1 ) <= $minreq->[0] ) )
-    {
-      @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); #say $tee "777b \@diff2: " . dump( @diff2 ); say $tee "777\@diff1: " . dump( @diff1 );
+  my @diff1 = diff( \@{ $el1 }, \@{ $elt1 } ); #say $tee "777\@diff1: " . dump( @diff1 );
+  my $dist;
+  my ( @factbag, @levbag, @stepbag, @da1, @da1par, @da2, @da2par, @diff2 );
+  #say $tee "777\scalar( \@diff1 ): " . dump( scalar( @diff1 ) ); say $tee "777\$minreq: " . dump( $minreq );
+  if ( ( scalar( @diff1 ) > 0 ) and ( scalar( @diff1 ) <= $minreq->[0] ) )
+  {
+    @diff2 = diff( \@{ $elt1 } , \@{ $el1 } ); #say $tee "777b \@diff2: " . dump( @diff2 ); say $tee "777\@diff1: " . dump( @diff1 );
 
-      my %h1 = map { split( /-/ , $_ ) } @diff1; #say $tee "THEN \%h1: " . dump( %h1 );
-      @da1 = keys %h1; #say $tee "THEN \@da1: " . dump( @da1 );
-      @da1par = values %h1; #say $tee "\@da1par: " . dump( @da1par );
-      my %h2 = map { split( /-/ , $_ ) } @diff2; #say $tee "THEN \%h2: " . dump( %h2 );
-      @da2 = keys %h2; #say $tee "THEN \@da2: " . dump( @da2 );
-      @da2par = values %h2; #say $tee "\@da2par: " . dump( @da2par );
+    my %h1 = map { split( /-/ , $_ ) } @diff1; #say $tee "THEN \%h1: " . dump( %h1 );
+    @da1 = keys %h1; #say $tee "THEN \@da1: " . dump( @da1 );
+    @da1par = values %h1; #say $tee "\@da1par: " . dump( @da1par );
+    my %h2 = map { split( /-/ , $_ ) } @diff2; #say $tee "THEN \%h2: " . dump( %h2 );
+    @da2 = keys %h2; #say $tee "THEN \@da2: " . dump( @da2 );
+    @da2par = values %h2; #say $tee "\@da2par: " . dump( @da2par );
 
-      my $c = 0;
-      foreach my $lev1 ( @da1par )
-      { #say $tee "\$e: " . dump( $e );
-        my $da1 = $da1[$c];
-        my $i = 0;
-        foreach my $lev2 ( @da2par )
+    my $c = 0;
+    foreach my $lev1 ( @da1par )
+    { #say $tee "\$e: " . dump( $e );
+      my $da1 = $da1[$c];
+      my $i = 0;
+      foreach my $lev2 ( @da2par )
+      {
+        my $da2 = $da2[$i];
+        if ( $da1 == $da2 )
         {
-          my $da2 = $da2[$i];
-          if ( $da1 == $da2 )
+          my $fact = $da1;
+          my $diffpar = abs( $lev1 - $lev2 ); #say $tee "22 \$diffpar: " . dump( $diffpar );
+          if ( ( $diffpar <= $minreq->[1] ) and ( $fact ne "" ) and ( $diffpar ne "" ) and ( $factlevels{stepsizes}{$fact} ne "" ) )
           {
-            my $fact = $da1;
-            my $diffpar = abs( $lev1 - $lev2 ); #say $tee "22 \$diffpar: " . dump( $diffpar );
-            if ( ( $diffpar <= $minreq->[1] ) and ( $fact ne "" ) and ( $diffpar ne "" ) and ( $factlevels{stepsizes}{$fact} ne "" ) )
-            {
-              push ( @factbag, $fact );
-              push ( @levbag, $diffpar );
-              push ( @stepbag, $factlevels{stepsizes}{$fact} );
-            }
+            push ( @factbag, $fact );
+            push ( @levbag, $diffpar );
+            push ( @stepbag, $factlevels{stepsizes}{$fact} );
           }
-          $i++;
         }
-        $c++;
+        $i++;
       }
+      $c++;
     }
+  }
 
-    unless ( ( scalar( @levbag ) == 0 ) or ( scalar( @factbag ) == 0 ) or ( scalar( @stepbag ) == 0 ) )
+  unless ( ( scalar( @levbag ) == 0 ) or ( scalar( @factbag ) == 0 ) or ( scalar( @stepbag ) == 0 ) )
+  {
+    my $ordist = scalar( @levbag ); #say $tee "\$ordist: " . dump( $ordist );
+    my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); #say $tee "777b\$rawdist: " . dump( $rawdist );
+    my ( $dist, $strength );
+
+    if ( $maxdist ne "" )
     {
-      my $ordist = scalar( @levbag ); #say $tee "\$ordist: " . dump( $ordist );
-      my $rawdist = pythagoras( \@factbag, \@levbag, \@stepbag ); #say $tee "777b\$rawdist: " . dump( $rawdist );
-      my ( $dist, $strength );
-
-      if ( $maxdist ne "" )
-      {
-        $dist = ( $rawdist / $maxdist );
-        $strength = ( 1 - $dist );
-      }
-
-      if ( ( $el3 ne "" ) and ( $elt3 ne "" ) and ( $condweight = "yes") )
-      {
-        $strength = ( $strength * $el3 * $elt3 );
-      }
-      return( { dist => $dist, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1,
-        diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par } );
+      $dist = ( $rawdist / $maxdist );
+      $strength = ( 1 - $dist );
     }
+
+    if ( ( $el3 ne "" ) and ( $elt3 ne "" ) and ( $condweight = "yes") )
+    {
+      $strength = ( $strength * $el3 * $elt3 );
+    }
+    return( { dist => $dist, strength => $strength, ordist => $ordist, rawdist => $rawdist, diff1 => \@diff1, diff2 => \@diff2, da1 => \@da1, da2 => \@da2, da1par => \@da1par, da2par => \@da2par } );
   }
 }
 
 
 sub calcmaxdist
 {
-  my ( $arr_ref, $factlevels_ref, $distn_ref ) = @_;
-  my @arr = @{ $arr_ref }; #say $tee "00\@arr: " . dump( @arr ); say $tee "00\$arr_ref: " . dump( $arr_ref );
-  my %distn = %{ $distn_ref };
+  my ( $arr_ref, $factlevels_ref ) = @_;
+  my @arr = @{ $arr_ref };
   my @rawdists;
   foreach my $el ( @arr )
   {
     foreach my $elt ( @arr )
-    { #say $tee "001el1 => $el->[1]: " . dump(  $el->[1] ); say $tee "001\elt1 => $elt->[1]: " . dump(  $elt->[1] );
-      #say $tee "001el3 => $el->[3]: " . dump(  $el->[3] ); say $tee "001\elt3 => $elt->[3]: " . dump(  $elt->[3] );
-      #say $tee "001el0 => $el->[0]: " . dump(  $el->[0] ); say $tee "001\elt0 => $elt->[0]: " . dump(  $elt->[0] );
-      my $h_r = calcdist( { el1 => $el->[1], elt1 => $elt->[1],
-        factlevels_ref => $factlevels_ref, distn_ref => $distn_ref, signal => "signal" } ); #say $tee "007\$h_r: " . dump( $h_r );
-      my %hash = %{ $h_r }; #say $tee "007\%hash: " . dump( %hash );
+    {
+      my $hash_ref = calcdist( $el->[1], $elt->[1], $factlevels_ref );
+      my %hash = %{ $hash_ref }; #say $tee "00\%hash: " . dump( %hash );
       push ( @rawdists, $hash{rawdist} );
     }
   }  #say $tee "00\@rawdists: " . dump( @rawdists );
@@ -596,40 +561,14 @@ sub calcmaxdist
 }
 
 
-sub exploredist
-{
-  my ( $arr_ref, $minreq_forgrad ) = @_;
-  my @arr = @{ $arr_ref };
-  my %distn;
-  foreach my $el ( @arr )
-  {
-    my $key =  $el->[0] ;
-    foreach my $elt ( @arr )
-    {
-      unless ( $el->[0] eq $elt->[0] )
-      {
-        my @diff1 = diff( \@{ $el->[1] }, \@{ $elt->[1] } );
-        my $scalar = scalar( @diff1 );
-        if ( ( $scalar > 0 ) and ( $scalar <= $minreq_forgrad->[0] ) )
-        {
-          $distn{$el->[0]}{$elt->[0]} = "y";
-        }
-      }
-    }
-  } #say $tee "IN EXPLORE \%distn: " .dump( \%distn );
-  return( \%distn );
-}
-
-
 sub wei
 {
   my ( $arr_ref, $relaxmethod, $overweightnearest, $parconcurrencies, $instconcurrencies, $count,
-    $factlevels_ref, $minreq_forgrad, $minreq_forinclusion, $minreq_forcalc, $minreq_formerge, $maxdist, $distn_ref ) = @_;
+    $factlevels_ref, $minreq_forgrad, $minreq_forinclusion, $minreq_forcalc, $minreq_formerge, $maxdist ) = @_;
   my @arr = @{ $arr_ref };
   #say $tee "ARR VERY_BEFORE: " . dump(@arr);
   my %factlevels = %{ $factlevels_ref };  #say $tee "AND \%factlevels: " . dump( %factlevels );
-  my %distn = %{ $distn_ref }; #say $tee "\%distn: " .dump( \%distn );
-
+  # my ( %magic, %wand, %spell, %bank );
 
   sub fillbank
   { #say $tee "NOW IN FILLBANK.";
@@ -645,7 +584,7 @@ sub wei
           { #say $tee "NOW CHECKING .";
 
             my $d_ref; #say $tee "\$el->[1] : " . dump( $el->[1] ); say $tee "\$elt->[1]: " . dump( $elt->[1] );
-            my ( $res_ref ) = calcdistgrad( $el->[1], $elt->[1], \%factlevels, $minreq_forgrad, $maxdist, $el->[3], $elt->[3], $condweight, \%distn, $el->[0], $elt->[0] );
+            my ( $res_ref ) = calcdistgrad( $el->[1], $elt->[1], \%factlevels, $minreq_forgrad, $maxdist, $el->[3], $elt->[3], $condweight );
 
             #if ( $res_ref ne "" )
             unless ( !keys %{ $res_ref } )
@@ -743,11 +682,11 @@ sub wei
                         {
                           if ( $orderedtrio eq $trio )
                           {
-                            push ( @{ $bank{$trio}{grads} }, ( - $grad ) );
+                            push ( @{ $bank{$trio}{grads} }, (- $grad ) );
                           }
                           else
                           {
-                            push ( @{ $bank{$trio}{grads} }, ( $grad ) );
+                            push ( @{ $bank{$trio}{grads} }, $grad );
                           }
                         }
                       }
@@ -880,7 +819,8 @@ sub wei
 
                       unless ( ( scalar( @boxgrads ) == 0 ) and ( scalar( @boxdists ) == 0 ) and ( scalar( @boxors ) == 0 ) )
                       {
-                        ( $soughtinc, $totdist, $totstrength ) = weightvals1( $elt->[1], \@boxgrads, \@boxdists, \@boxors, $minreq_forcalc, \@factbag, \@levbag, \@stepbag, $elt->[2], \%factlevels, $maxdist, $el->[3], $elt->[3], $condweight, $distn_ref, $el->[0], $elt->[0] );
+                        ( $soughtinc, $totdist, $totstrength ) = weightvals1( $elt->[1], \@boxgrads, \@boxdists, \@boxors, $minreq_forcalc, \@factbag, \@levbag, \@stepbag, $elt->[2], \%factlevels, $maxdist, $el->[3], $elt->[3], $condweight );
+
 
                         unless ( ( $soughtinc eq "" ) or ( $totdist eq "" ) )
                         {
@@ -1393,24 +1333,19 @@ sub interlinear
   my @lines = <SOURCEFILE>;
   close SOURCEFILE;
 
+  say $tee "Preparing the datasieries.";
   my $aarr_ref;
-  say $tee "PREPARING THE DATASERIES. ";
   ( $aarr_ref, $optformat ) = preparearr( \@lines );
 
   my @aarr = @{ $aarr_ref };
 
-  say $tee "CHECKING LEVELS AND FACTORS. ";
+  say $tee "Checking factors and levels.";
   my %factlevels = prepfactlev( @aarr );
 
   my ( $factlev_ref ) = tellstepsize( \%factlevels );
   my %factlev = %{ $factlev_ref }; #say $tee "\%factlev: " . dump( %factlev );
 
-  say $tee "PRELIMINARLY EXPLORING THE SPACE. ";
-
-  my $distn_ref = exploredist( \@aarr, $minreq_forgrad );
-  my %distn = %{ $distn_ref };
-
-  my $maxdist = calcmaxdist( \@aarr, \%factlev, \%distn ); #say $tee "001\$maxdist: " . dump( $maxdist );
+  my $maxdist = calcmaxdist( \@aarr, \%factlev ); #say $tee "001\$maxdist: " . dump( $maxdist );
 
   my $count = 0;
   while ( $count < $maxloops )
@@ -1431,9 +1366,17 @@ sub interlinear
     my ( @limbo_wei, @limbo_purelin, @limbo_near, @limbo, %bank, %wand );
 
 
+    #if ( ( $mode__ eq "vault" ) or ( $mode__ eq "mix" ) )
+    #{
+    #  @limbo_vault = vault( \@arr, $relaxlimit, $relaxmethod, $overweightnearest, $parconcurrencies, $instconcurrencies, $count, \%factlev );
+    #}
+    #say $tee "OBTAINED limbo_vault: " . dump( @limbo_vault );
+    #say $tee "THERE ARE " . scalar( @limbo_vault ) . " ITEMS IN THIS LOOP , NUMBER " . ( $count + 1 ). ", 1, FOR GLOBALLY WEIGHTED GRADIENT INTERPOLATION.";
+
+
     if ( ( $mode__ eq "wei" ) or ( $mode__ eq "mix" ) )
     {
-      @limbo_wei = wei( \@arr, $relaxmethod, $overweightnearest, $parconcurrencies, $instconcurrencies, $count, \%factlev, $minreq_forgrad, $minreq_forinclusion, $minreq_forcalc, $minreq_formerge, $maxdist, $distn_ref );
+      @limbo_wei = wei( \@arr, $relaxmethod, $overweightnearest, $parconcurrencies, $instconcurrencies, $count, \%factlev, $minreq_forgrad, $minreq_forinclusion, $minreq_forcalc, $minreq_formerge, $maxdist );
       say $tee "THERE ARE " . scalar( @limbo_wei ) . " ITEMS IN THIS LOOP , NUMBER " . ( $count + 1 ). ", 1, FOR WEIGHTED GRADIENT INTERPOLATION OF THE NEAREST NEIGHBOUR.";
     }
     #say $tee "OBTAINED LIMBO_WEI: " . dump( @limbo_wei );
@@ -1475,17 +1418,17 @@ sub interlinear
     #  @limbo = mixlimbo( \@limbo_prov, \@limbo_near, $presence, $linearprecedence, \@weights );
     #}
 
-    #say $tee "OBTAINED LIMBO: " . dump( @limbo );
+    say $tee "OBTAINED LIMBO: " . dump( @limbo );
     say $tee "MIXING THE ARRAY UPDATES " . ( $count + 1 ) . " for $sourcefile";
     say $tee "THERE ARE " . scalar( @limbo ) . " ITEMS COMING OUT FROM THIS MIX " . ( $count + 1 );
 
     if ( ( scalar( @limbo ) == 0 ) )
     {
-      #say $tee "ARR END: " . dump( @arr );
+      say $tee "ARR END: " . dump( @arr );
       last;
     }
 
-    #say $tee "ARR BEFORE: " . dump( @arr );
+    say $tee "ARR BEFORE: " . dump( @arr );
     foreach my $el ( @limbo )
     { #say $tee "EL AGAIN: " . dump( $el );
       foreach $elt ( @arr )
@@ -1520,7 +1463,7 @@ sub interlinear
     }
     @arr2 = @arr ;
     say $tee "INSERTING THE ARRAY UPDATES " . ( $count + 1 ) . " for $sourcefile";
-    #say $tee "ARR AFTER: " . dump( @arr );
+    say $tee "ARR AFTER: " . dump( @arr );
     $count++;
   }
   return( @arr );
@@ -1600,24 +1543,24 @@ Sim::OPT::Interlinear
 
 
 Interlinear is a program for computing the missing values in multivariate datasieries pre-prepared in csv format.
-The program can adopt the following algorithmic strategies and intermix their results:
+The program can adopt the following algorithmic strategies and intermix their result:
 
-a) a propagating distance-weighted gradient-based strategy (by far the best one so far, keeping into account that the behaviour of factors is often not linear and there are curvatures all around the design space);
+a) a propagating distance-weighted gradient-based strategy (by far the best one so far, keeping into account that the behaviour of factors is often not linear and there are curvatures all aroung the design space);
 
-b) pure linear interpolation (one may want to use this in some occasions: for example, with factorials);
+b) pure linear interpolation (one may want to use this in some occasions: for example, on factorials);
 
 c) nearest neighbour (a strategy of last resort. One may want to use it to unlock a computation which is based on data which are too sparse to proceed, or when nothing else works).
 
 A configuration file should be prepared following the example in the "examples" folder in this distribution.
-If the configuration file is incomplete or missing, the will program adopt its own defaults, sticking to the distance-weighted gradient-based strategy.
+If the configuration file is incomplete or missing, the program adopts its own defaults, exploiting the distance-weighted gradient-based strategy.
 
 The only variable that must mandatorily be specified in a configuration file is $sourcefile : the Unix path to the source file containining the dataseries.
 
-The source file has to be prepared by listing in each column the values (levels) of the parameters (factors, variables), and putting in the last column the values of the objective function, when present.
+The source file has to be prepared by listing in each column the values (levels) of the parameters (factors, variables), putting in the last column the objective function value, when present.
 
 The parameter number is given by the position of the column (i.e. column 4 host parameter 4).
 
-Here below is shown an example of dataseries of 3 parameters assuming 3 levels each. having missing objecive function entries.
+Here below is shown an example of multivatiate dataseries of 3 parameters assuming 3 levels each. having with missing objecive function entries.
 
 
 1,1,1,1.234
